#!/bin/sh
#
# ------------------------------------------------------------------------------
#   Copyright 2010 Oracle
#
#   Licensed under the Apache License, Version 2.0 (the "License");
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.
# ------------------------------------------------------------------------------
#
# runBOMTests.sh is a shell script that tests various combinations of
# UTF-* encoding, Byte-Order-Mark (BOM), 'charset' values, XML prologs
# and 'encoding' pseudo attribute values.
#
# arguments:
#   $1 - URL of service that implements the IBaseDataTypesDocLitW
#        portType
#
#   $2 - SOAP version of service - one of "1.1" or "1.2"
#
#   $3 - sub-directory to use for messages - e.g. RetString-WSAddr

# run_test
#
# Executes the PostSOAP program and reports any errors
#
# arguments:
#   $1 - URL of service that implements the IBaseDataTypesDocLitW
#        portType
#
#   $2 - SOAP version of service - one of "1.1" or "1.2"
#   
#   $3 - file name of file that contains request
#
#   $4 - encoding value for 'charset'
#
run_test()
{
    echo -e "\n`basename $3`"

    if [ "$#" -eq "4" ]
    then
        #
        # Override the encoding that PostSOAP calculates with the value supplied in $4
        #
        java ${JAVA_OPTIONS} org.apache.http.client.PostSOAP -u $1 -s $2 -f $3 -a http://tempuri.org/IBaseDataTypesDocLitW/RetString -e $4
    else
        #
        # Let PostSOAP figure out the encoding (defaults to "UTF-8" if there is no BOM)
        #
        java ${JAVA_OPTIONS} org.apache.http.client.PostSOAP -u $1 -s $2 -f $3 -a http://tempuri.org/IBaseDataTypesDocLitW/RetString
    fi

    if [ "$?" -eq "0" ]
    then
        echo -e "\tsuccess"
    else
        echo -e "\tfailure"
    fi
}

if [ ! "$#" -eq "3" ]
then
    echo "Usage: runBOMTests.sh <service URI> <SOAP version> <message directory>"
    echo "<service URI> - HTTP URI of service endpoint"
    echo "<SOAP version> - one of \"1.1\" or \"1.2\""
    echo "<message directory> - a subdir of testMessages e.g. 'testMessages/RetString-WSAddr'"
    exit
fi

SAVE_JAVA_OPTIONS="${JAVA_OPTIONS}"

SAVE_CLASSPATH="${CLASSPATH}"

# Configure message logger/monitor via Java system properties. This
# can be done externally to this script.
#
#export JAVA_OPTIONS="${JAVA_OPTIONS} -Dhttp.proxyHost=localhost -Dhttp.proxyPort=8080"

#
# Cygin uses funny path separators
#
if [ "$OSTYPE" = "cygwin" ]
then
    export CLASSPATH="./bin;./lib/httpclient-4.0.1.jar;./lib/httpcore-4.0.1.jar;./lib/commons-logging-1.1.1.jar;${CLASSPATH}"
else
    export CLASSPATH="./bin:./lib/httpclient-4.0.1.jar:./lib/httpcore-4.0.1.jar:./lib/commons-logging-1.1.1.jar:${CLASSPATH}"
fi

echo -e "\nBOM Tests"
echo "--------------------------------------------------------------------------------"
echo "        Target Endpoint: ${1}"
echo "           SOAP Version: ${2}"
echo "Test Message Source Dir: ${3}"

# UTF-8 encoding, UTF-8 BOM, no XML prolog
run_test $1 $2 ${3}/SOAP${2}-RetString-UTF-8-BOM-NoProlog.txt

# UTF-8 encoding, UTF-8 BOM, XML prolog with encoding="UTF-16BE"
run_test $1 $2 ${3}/SOAP${2}-RetString-UTF-8-BOM-Prolog-UTF-16BE.txt

# UTF-16BE encoding, UTF-16BE BOM, XML prolog with encoding="UTF-16BE"
run_test $1 $2 ${3}/SOAP${2}-RetString-UTF-16BE-BOM-Prolog-UTF-16BE.txt

# UTF-16BE encoding, UTF-16BE BOM, no XML prolog
run_test $1 $2 ${3}/SOAP${2}-RetString-UTF-16BE-BOM-NoProlog.txt

# UTF-16LE encoding, UTF-16LE BOM, XML prolog with encoding="UTF-16LE"
run_test $1 $2 ${3}/SOAP${2}-RetString-UTF-16LE-BOM-Prolog-UTF-16LE.txt

# UTF-16LE encoding, UTF-16LE BOM, no XML prolog
run_test $1 $2 ${3}/SOAP${2}-RetString-UTF-16LE-BOM-NoProlog.txt

JAVA_OPTIONS="${SAVE_JAVA_OPTIONS}"

unset SAVE_JAVA_OPTIONS

CLASSPATH="${SAVE_CLASSPATH}"

unset SAVE_CLASSPATH
